@@ -106,7 +106,7 @@ public final class CloudmarkSpamHandler extends SpamHandler {
             for (int i = 0; i < mailMessage.length; i++) {
                 final MailTransport transport = MailTransport.getInstance(session);
                 try {
-                    if (isEmpty(targetSpamEmailAddress)) {
+                    if (com.openexchange.java.Strings.isEmpty(targetSpamEmailAddress)) {
                         LOG.debug("There is no value configured for 'com.openexchange.spamhandler.cloudmark.targetSpamEmailAddress', cannot process spam reporting to server.");
                     } else {
                         SendRawProperties sendRawProperties = MailTransport.SendRawProperties.newInstance()
@@ -147,7 +147,7 @@ public final class CloudmarkSpamHandler extends SpamHandler {
 
     @Override
     public void handleHam(final int accountId, final String fullname, final String[] mailIDs, final boolean move, final Session session) throws OXException {
-    	ConfigurationService configuration = services.getService(ConfigurationService.class);
+        ConfigurationService configuration = services.getService(ConfigurationService.class);
         String targetHamEmailAddress = configuration.getProperty("com.openexchange.spamhandler.cloudmark.targetHamEmailAddress", "").trim();
 
         MailAccess<?, ?> mailAccess = null;
@@ -159,7 +159,7 @@ public final class CloudmarkSpamHandler extends SpamHandler {
             for (int i = 0; i < mailMessage.length; i++) {
                 final MailTransport transport = MailTransport.getInstance(session);
                 try {
-                    if (isEmpty(targetHamEmailAddress)) {
+                    if (com.openexchange.java.Strings.isEmpty(targetHamEmailAddress)) {
                         LOG.debug("There is no value configured for 'com.openexchange.spamhandler.cloudmark.targetHamEmailAddress', cannot process ham reporting to server.");
                     } else {
                         SendRawProperties sendRawProperties = MailTransport.SendRawProperties.newInstance()
@@ -177,15 +177,9 @@ public final class CloudmarkSpamHandler extends SpamHandler {
             }
 
             if (move) {
-            	String targetSpamFolder = configuration.getProperty("com.openexchange.spamhandler.cloudmark.targetSpamFolder", "1").trim();
+                String targetSpamFolder = configuration.getProperty("com.openexchange.spamhandler.cloudmark.targetSpamFolder", "1").trim();
                 if (!targetSpamFolder.equals("0")) {
-                    try {
-                        mailAccess.getMessageStorage().moveMessages(fullname, "INBOX", mailIDs, true);
-                    } finally {
-                        if (null != mailAccess) {
-                            mailAccess.close(true);
-                        }
-                    }
+                    mailAccess.getMessageStorage().moveMessages(fullname, "INBOX", mailIDs, true);
                 }
             }
         } finally {
@@ -206,18 +200,6 @@ public final class CloudmarkSpamHandler extends SpamHandler {
         return false;
     }
 
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
     /**
      * Gets the session users sender address.
      *
@@ -240,4 +222,5 @@ public final class CloudmarkSpamHandler extends SpamHandler {
             return null;
         }
     }
+
 }
